@@ -74,7 +74,7 @@ linearShrinkLWEst <- function(dat) {
   m_n <- matrixStats::sum2(sample_cov_mat * idn_pn) / p_n
   d_n_2 <- matrixStats::sum2((sample_cov_mat - m_n * idn_pn)^2) / p_n
   b_bar_n_2 <- apply(
-    dat, 1,
+    safeColScale(dat, center = TRUE, scale = FALSE), 1,
     function(x) {
       matrixStats::sum2((tcrossprod(x) - sample_cov_mat)^2)
     }
@@ -315,6 +315,10 @@ taperingEst <- function(dat, k) {
 #' nlShrinkLWEst(dat = mtcars)
 #' @export
 nlShrinkLWEst <- function(dat) {
+
+  # scale the data
+  dat <- safeColScale(dat, center = TRUE, scale = FALSE)
+
   # get the dimensions of the data
   n <- nrow(dat)
   p <- ncol(dat)
